pub struct TimeclockReport { /* private fields */ }Expand description
Typed request for Gingr timeclock reports used as labor workflow evidence.
Implementations
Sourceimpl TimeclockReport
impl TimeclockReport
Sourcepub fn builder() -> TimeclockReportBuilder
pub fn builder() -> TimeclockReportBuilder
Starts a builder that makes each provider parameter explicit before request capture.