pub struct TimeclockReportBuilder { /* private fields */ }Expand description
Builder for Gingr timeclock report filters.
Implementations
Sourceimpl TimeclockReportBuilder
impl TimeclockReportBuilder
Sourcepub fn date_range(self, start_date: Date, end_date: Date) -> Self
pub fn date_range(self, start_date: Date, end_date: Date) -> Self
Scopes the labor report to a provider date range.
Sourcepub fn location_id(self, location_id: LocationId) -> Self
pub fn location_id(self, location_id: LocationId) -> Self
Scopes the Gingr endpoint request to a location.
Sourcepub fn include_deleted(self, include_deleted: bool) -> Self
pub fn include_deleted(self, include_deleted: bool) -> Self
Includes deleted provider records when Gingr supports that filter.
Sourcepub fn include_clocked_in(self, include_clocked_in: bool) -> Self
pub fn include_clocked_in(self, include_clocked_in: bool) -> Self
Includes currently clocked-in users in the labor report.
Sourcepub fn build(self) -> Result<TimeclockReport>
pub fn build(self) -> Result<TimeclockReport>
Finalizes the provider request descriptor after required fields are present and wrappers have validated local invariants.